/* GTKabale - Solitaire game for lazy people

   Copyright (C) 1999 Ren Seindal (rene@seindal.dk)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#include "game.h"
#include "display.h"

gboolean
on_delete_event                        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
    gtk_exit(0);
    return FALSE;
}


void
on_quit_clicked                        (GtkButton       *button,
                                        gpointer         user_data)
{
    gtk_exit(0);
}


void
on_start_clicked                       (GtkButton       *button,
                                        gpointer         user_data)
{
#ifdef DEBUG
    g_print("start game\n");
#endif /* DEBUG */
    start_game(FALSE);
}

void
on_same_clicked                        (GtkButton       *button,
                                        gpointer         user_data)
{
#ifdef DEBUG
    g_print("start game\n");
#endif /* DEBUG */
    start_game(TRUE);
}

void
on_finish_clicked                      (GtkButton       *button,
                                        gpointer         user_data)
{
#ifdef DEBUG
    g_print("finish game\n");
#endif /* DEBUG */
    finish_game();
}


void
on_help_clicked                        (GtkButton       *button,
                                        gpointer         user_data)
{
#ifdef DEBUG
    g_print("help toggled\n");
#endif /* DEBUG */

    set_help_mode(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)));
}

gboolean
on_key_press_event                     (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data)
{
#ifdef DEBUG
    g_print("key %d %s\n", event->keyval, event->string);
#endif /* DEBUG */

    if (event->string != NULL) {
	switch (event->string[0]) {
	case '0': case '1': case '2': case '3':
	case '4': case '5': case '6': case '7':
	    make_one_move(event->string[0] - '0');
	    return TRUE;

	case '8':
	    make_one_move('0');
	    return TRUE;

	case ' ':
	case '\n':
	    make_one_move(-1);
	    return TRUE;

	}
    }

    return FALSE;
}



gboolean
on_stack_button_press_event            (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data)
{
    guint stack;

#ifdef DEBUG
    g_print("button %d %d %d - data %d\n", 
	    event->button,
	    (gint)event->x, (gint)event->y,
	    GPOINTER_TO_UINT(user_data));
#endif /* DEBUG */

    gtk_window_set_focus(GTK_WINDOW(gtk_widget_get_toplevel(widget)), widget);

    if (event->button == 3)
	stack = -1;
    else {
	stack = GPOINTER_TO_UINT(user_data);
	if (stack == 0 && click_on_back((gint)event->y))
	    stack = -1;
    }
    make_one_move(stack);

    return FALSE;
}
