/* GTKabale - Solitaire game for lazy people

   Copyright (C) 1999 Ren Seindal (rene@seindal.dk)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 */

#ifndef DATA_H_
#define DATA_H_

#include <glib.h>

#define CARDS (52)
#define STACKS (7)

#ifndef nil
#define nil ((void *)0)
#endif

#ifndef pred
#define pred(x) ((x) - 1)
#endif

#ifndef succ
#define succ(x) ((x) + 1)
#endif

typedef enum { _FALSE = 0, _TRUE = 1 } boolean;

typedef enum { 
    hearts, spades, diamonds, clubs 
} suit_t;

typedef enum { 
    none, ace, two, three, 
    four, five, six, seven,
    eight, nine, ten, jack,
    queen, king
} value_t;


typedef struct card_t {
    suit_t s;
    value_t v;
    struct card_t *n;
} card_t;

typedef unsigned int stacknum_t;
typedef unsigned int stackindex_t;

typedef struct stack_t {
    card_t *hidden;
    card_t *faceup;
    card_t *last;
} stack_t;

typedef struct stack_t layout_t[8];
typedef value_t aces_t[4];

extern struct card_t *deck;
extern struct card_t *top;

extern stack_t layout[8];
extern value_t aces[4];

extern int cardsleft, turnsleft;
extern int times_played, times_won;

extern void initdata(gboolean same);
extern void flip_card(stacknum_t sn);

extern boolean move_stack_to_ace(stacknum_t src);
extern boolean move_stacks(stacknum_t src, stacknum_t dest);

extern boolean move_deck_to_stack(stacknum_t dest);
extern boolean move_deck_to_ace(void);
extern boolean pop_deck(void);
extern card_t *revert_deck(card_t *from);

extern boolean find_move(stackindex_t *src, stackindex_t *dest);
extern int find_unique_move(stackindex_t src, stackindex_t *dest);

extern boolean succes(void);
extern boolean failure(void);

#endif /* DATA_H_ */
